@@ -1,7 +1,5 @@
-import tempfile
-import subprocess
-from mw2fcitx.utils import console
 import re
+from ..utils import console
 
 
 def gen(text, **kwargs):
@@ -18,4 +16,4 @@ def gen(text, **kwargs):
     else:
         print(text)
     console.info("Dictionary generated.")
-    return text
\ No newline at end of file
+    return text
