@@ -1,10 +1,8 @@
-from mw2fcitx.utils import console
-import sys
 import re
-
 from pypinyin import lazy_pinyin
 import opencc
-from mw2fcitx.utils import manual_fix
+from ..utils import console
+from ..utils import manual_fix
 
 
 def export(words):
@@ -18,17 +16,6 @@ def export(words):
         if not HANZI_RE.match(line):
             continue
 
-        # Skip single character & too long pages
-        if not 1 < len(line):
-            continue
-
-        # Skip list pages
-        if line.endswith(('列表', '对照表')):
-            continue
-
-        if last_word and len(last_word) >= 4 and line.startswith(last_word):
-            continue
-
         pinyin = "'".join(lazy_pinyin(line))
         if pinyin == line:
             # print("Failed to convert, ignoring:", pinyin, file=sys.stderr)
@@ -36,7 +23,7 @@ def export(words):
 
         if manual_fix(line):
             pinyin = manual_fix(line)
-            console.debug(f"Fixing {line} to {pinyin}", file=sys.stderr)
+            console.debug(f"Fixing {line} to {pinyin}")
 
         last_word = line
 
@@ -48,4 +35,4 @@ def export(words):
 
     if count % 1000 != 0 or count == 0:
         console.debug(str(count) + " converted")
-    return result
\ No newline at end of file
+    return result
