@@ -1,9 +1,12 @@
-from mw2fcitx.fetch import fetch_all_titles
-from mw2fcitx.utils import dedup
-from mw2fcitx.utils import console
+# pylint: disable=import-outside-toplevel
+
 import os
 import sys
 
+from .fetch import fetch_all_titles
+from .utils import dedup
+from .utils import console
+
 
 class MWFPipeline():
 
@@ -14,10 +17,15 @@ class MWFPipeline():
         self.exports = ""
         self.dict = ""
 
-    def load_titles(self, titles):
-        if type(titles) == type(""):
+    def load_titles(self, titles, limit=-1, replace=False):
+        if isinstance(titles, str):
             titles = titles.split("\n")
-        self.titles = titles
+        if limit >= 0:
+            titles = titles[:limit]
+        if replace:
+            self.titles = titles
+        else:
+            self.titles.extend(titles)
         console.debug("{} title(s) imported.".format(len(titles)))
         self.words = self.titles
 
@@ -35,11 +43,12 @@ class MWFPipeline():
             self.write_titles_to_file(kwargs.get("output"))
 
     def load_titles_from_file(self, filename, **kwargs):
+        limit = kwargs.get("file_title_limit") or kwargs.get(
+            "title_limit") or -1
         if not os.access(filename, os.R_OK):
             console.error("File {} is not readable".format(filename))
             sys.exit(1)
-        self.load_titles(open(filename, "r").read())
-        self.post_load(**kwargs)
+        self.load_titles(open(filename, "r").read(), limit=limit)
 
     def fetch_titles(self, **kwargs):
         titles = fetch_all_titles(self.api_path, **kwargs)
@@ -49,10 +58,10 @@ class MWFPipeline():
     def reset_words(self):
         self.words = self.titles
 
-    def convert_to_words(self, pipelines=[]):
+    def convert_to_words(self, pipelines):
         console.debug("Running {} pipelines".format(len(pipelines)))
         cnt = 0
-        if type(pipelines) == type(self.convert_to_words):
+        if callable(pipelines):
             pipelines = [pipelines]
         titles = self.titles
         for i in pipelines:
@@ -60,7 +69,10 @@ class MWFPipeline():
             console.debug("Running pipeline {}/{} ({})".format(
                 cnt, len(pipelines), i.__name__ or "anonymous function"))
             titles = i(titles)
+        console.debug("Deduplicating {} items".format(len(titles)))
         self.words = dedup(titles)
+        console.debug("Deduplication completed. {} items left.".format(
+            len(self.words)))
 
     def export_words(self, converter="opencc", **kwargs):
         if converter == "opencc":
@@ -68,7 +80,7 @@ class MWFPipeline():
                 len(self.words)))
             from mw2fcitx.exporters.opencc import export
             self.exports = export(self.words, **kwargs)
-        elif type(converter) == type(self.export_words):
+        elif callable(converter):
             console.debug("Exporting {} words with custom converter".format(
                 len(self.words)))
             self.exports = converter(self.words, **kwargs)
@@ -81,7 +93,8 @@ class MWFPipeline():
             dest = kwargs.get("output")
             if not dest:
                 console.error(
-                    "Dictgen 'pinyin' can only output to files. Please give the file path in the 'output' argument."
+                    "Dictgen 'pinyin' can only output to files.\n" +
+                    "Please give the file path in the 'output' argument."
                 )
                 return
             pinyin(self.exports, **kwargs)
@@ -89,4 +102,4 @@ class MWFPipeline():
             from mw2fcitx.dictgen import rime
             self.dict = rime(self.exports, **kwargs)
         else:
-            console.error("No such dictgen: {}".format(generator))
\ No newline at end of file
+            console.error("No such dictgen: {}".format(generator))
