@@ -1,10 +1,12 @@
-from mw2fcitx.tweaks.moegirl import tweaks
+from .tweaks.moegirl import tweaks
 
 exports = {
     "source": {
         "api_path": "https://zh.moegirl.org.cn/api.php",
         "kwargs": {
-            "title_limit": 120,
+            "api_title_limit": 120,
+            "file_title_limit": 60,
+            "title_limit": 240,
             "output": "titles.txt"
         }
     },
@@ -25,4 +27,4 @@ exports = {
             "output": "moegirl.dict"
         }
     }]
-}
\ No newline at end of file
+}
